@@ -1,7 +1,6 @@
 import logging
 from threading import local
 
-from django.core.signals import request_finished
 from django.utils.importlib import import_module
 
 from signals import finished, process, warning
@@ -23,6 +22,7 @@ def add_signal(signal, **kw):
     kw['sender'] = kw['sender'].__name__
     _locals.signals.append(kw)
 
+
 def reset(**kw):
     setup()
     _locals.signals = []
@@ -39,16 +39,7 @@ def process_signals(signal, **kw):
         process.send(request=kw['request'], **data)
 
 
-def config(reporters=None, *args, **kw):
-    if not reporters:
-        try:
-            from django.conf import settings
-            reporters = getattr(settings, 'DJANGO_PARANOIA_REPORTERS', [])
-        except ImportError:
-            # This can occur when running the tests, because at this time
-            # the settings module isn't created. TODO: fix this.
-            return
-
+def config(reporters, *args, **kw):
     for reporter in reporters:
         try:
             to = import_module(reporter).report
